<?php 
	/*
	** File: index.php
	** Description: main script
	** Created: 01/04/2000
	** Version: 1.0
	** Author: Leon Atkinson
	** Email: leon@leonatkinson.com
	*/

	/*
	** Create constants used for including modules or
	** creating URIs.  Note that this code tries to figure
	** it out by context, but uses environment variables
	** as made available by Apache for Unix.  For another OS
	** or Web server, you can either use appropriate variables,
	** or just hardcode the paths below.
	*/
	
	//This should contain something like www.zend.com
	define("SERVER_NAME", $SERVER_NAME);

	//This will usually find index.php, but you can call your
	//script anything and it will work.
	eregi("([^/\\]*)$", $SCRIPT_FILENAME, $match);
	define("SCRIPT_NAME", $match[0]);

	//This gets the path on the local filesystem to where we
	//expect the modules diectory to be.  It might contain
	// something like /usr/local/apache
	define("APPLICATION_ROOT", eregi_replace("[/\\]htdocs[/\\]".SCRIPT_NAME, "", $SCRIPT_FILENAME));
	define("MODULE", APPLICATION_ROOT . "/modules");

	//This gets the path part of the URI.  It should get something
	//like /~leon/fe/htdocs/, but it could be just /
	define("EXTERNAL_PATH", eregi_replace(SCRIPT_NAME, "", $SCRIPT_NAME));


	/* 
	** set constants
	*/
	if(!include(MODULE . "/utility/configuration"))
	{
		print("Unable to include \"configuration\"<br>\n");
		exit();
	}

	/*
	** get library of standard functions
	*/
	if(!include(MODULE . "/utility/standard_library"))
	{
		print("Unable to include \"standard_library\"<br>\n");
		exit();
	}

	/*
	** perform init code needed with every page view
	*/
	if(!include(MODULE . "/utility/initialization"))
	{
		print("Unable to include \"initialization\"<br>\n");
		exit();
	}


	/*
	** Execute action module, if requested.
	** Check for actions that include paths or other suspicious characters.
	*/
	if(isset($ACTION) AND ($ACTION != ""))
	{
		if(eregi('^[A-Z_0-9]*$', $ACTION) AND
			file_exists(MODULE . "/action/$ACTION"))
		{
			//try, as much as possible, to disallow actions from being interrupted
			set_time_limit(ACTION_TIME_LIMIT);
			$userAbortOrig = ignore_user_abort(TRUE);
			
			if(!include(MODULE . "/action/$ACTION"))
			{
				array_push($ActionResults, "\"$ACTION\" failed!");
			}
			
			//restore default settings
			set_time_limit(DEFAULT_TIME_LIMIT);
			ignore_user_abort($userAbortOrig);
		}
		else 
		{
			array_push($ActionResults, "\"$ACTION\" is not a valid action.");
		}
	}

	/*
	** include array of screen information
	*/
	require(MODULE . "/utility/ScreenInfo");

	/*
	** If we aren't given a screen, go home
	*/
	if(!(isset($SCREEN)) OR ($SCREEN==""))
	{
		$SCREEN="welcome";
	}


	/*
	** If screen is bad, go home
	*/
	if(!(file_exists(MODULE . "/screen/$SCREEN")) OR 
		(!isset($ScreenInfo[$SCREEN])))
	{
		$SCREEN="welcome";
	}


	/*
	** Start page
	*/
	print('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ');
	print('"http://www.w3.org/TR/html40/loose.dtd">');
	print("\n");
	
	print("<HTML>\n");
	print("<HEAD>\n");
	print("<TITLE>" . $ScreenInfo[$SCREEN][SI_TITLE] . "</TITLE>\n");


	/*
	** Meta tags
	*/
	print("<META NAME=\"description\" CONTENT=\"".$ScreenInfo[$SCREEN][SI_DESCRIPTION]."\">\n");
	print("<META NAME=\"keywords\" CONTENT=\"".$ScreenInfo[$SCREEN][SI_KEYWORDS]."\">\n");
	print("<META NAME=\"distribution\" CONTENT=\"global\">\n");

	print("</HEAD>\n");

	print("<BODY BGCOLOR=\"white\">\n");


	/*
	** go to layout module, that will in turn use navigation and screen modules
	*/
	if(!include(MODULE . "/layout/".$ScreenInfo[$SCREEN][SI_LAYOUT]))
	{
		print("An error occured while laying out the page<br>\n");
	}


	/*
	** close page
	*/
	print("</BODY>\n");
	print("</HTML>\n");
?>
